@@ -237,18 +237,62 @@ class VehicleMonitoringUseCase(BaseProcessor):
             if context is None:
                 context = ProcessingContext()
             
+            # Validate input data
+            if not isinstance(data, (list, dict)) or (isinstance(data, list) and not data):
+                self.logger.warning("No valid detection data provided")
+                vehicle_counting_summary = {
+                    "total_objects": 0,
+                    "by_category": {},
+                    "detections": []
+                }
+                general_counting_summary = vehicle_counting_summary.copy()
+                context.mark_completed()
+                result = self.create_result(
+                    data={
+                        "general_counting_summary": general_counting_summary,
+                        "counting_summary": vehicle_counting_summary,
+                        "zone_analysis": {},
+                        "alerts": [],
+                        "total_vehicles": 0,
+                        "zones_count": 0,
+                        "events": {"current_frame": []},
+                        "tracking_stats": {"current_frame": []},
+                        "track_ids_info": self.get_track_ids_info()
+                    },
+                    usecase=self.name,
+                    category=self.category,
+                    context=context
+                )
+                result.summary = "No vehicles detected in the scene"
+                result.insights = ["No vehicles detected in the scene"]
+                result.predictions = []
+                result.metrics = {
+                    "total_vehicles": 0,
+                    "processing_time": time.time() - start_time,
+                    "input_format": context.input_format.value if context.input_format else "unknown",
+                    "confidence_threshold": config.confidence_threshold,
+                    "zones_analyzed": 0,
+                    "detection_rate": 0.0,
+                    "coverage_percentage": 0.0,
+                    "unique_vehicles": 0,
+                    "tracking_efficiency": 0.0,
+                    "zone_metrics": {}
+                }
+                return result
+            
             # Detect input format
             input_format = match_results_structure(data)
             context.input_format = input_format
             context.confidence_threshold = config.confidence_threshold
             
             self.logger.info(f"Processing vehicle monitoring with format: {input_format.value}")
+            self.logger.debug(f"Input data: {data}")
             
             # Step 1: Apply confidence filtering
             processed_data = data
             if config.confidence_threshold is not None:
                 processed_data = filter_by_confidence(processed_data, config.confidence_threshold)
-                self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
+                self.logger.debug(f"After confidence filtering: {len(processed_data)} detections")
             
             # Step 2: Apply category mapping if provided
             if config.index_to_category:
@@ -259,7 +303,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             vehicle_processed_data = processed_data
             if config.target_vehicle_categories:
                 vehicle_processed_data = filter_by_categories(processed_data.copy(), config.target_vehicle_categories)
-                self.logger.debug(f"Applied vehicle category filtering for: {config.target_vehicle_categories}")
+                self.logger.debug(f"After category filtering: {len(vehicle_processed_data)} vehicle detections")
             
             # Step 2.6: Apply bbox smoothing if enabled
             if config.enable_smoothing:
@@ -273,27 +317,28 @@ class VehicleMonitoringUseCase(BaseProcessor):
                         enable_smoothing=True
                     )
                     self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
-                
+                self.logger.debug(f"Before smoothing: {vehicle_processed_data}")
                 vehicle_processed_data = bbox_smoothing(vehicle_processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
-                self.logger.debug(f"Applied bbox smoothing with {len(vehicle_processed_data)} smoothed detections")
+                self.logger.debug(f"After smoothing: {len(vehicle_processed_data)} vehicle detections")
             
             # Step 2.7: Apply advanced tracking if enabled
             if config.enable_tracking:
                 try:
                     from ..advanced_tracker import AdvancedTracker
                     from ..advanced_tracker.config import TrackerConfig
-                    
+                    # Create tracker instance if it doesn't exist (preserves state across frames)
                     if self.tracker is None:
                         tracker_config = TrackerConfig()
                         self.tracker = AdvancedTracker(tracker_config)
-                        self.logger.info("Initialized AdvancedTracker for vehicle tracking")
-                    
-                    vehicle_processed_data = self.tracker.update(vehicle_processed_data)
-                    self.logger.debug("Applied advanced tracking to vehicle detections")
-                
+                        self.logger.info("Initialized AdvancedTracker for Vehicle tracking")
+                    # The tracker expects the data in the same format as input
+                    # It will add track_id and frame_id to each detection
+                    vehicle_processed_data  = self.tracker.update(vehicle_processed_data)
                 except Exception as e:
+                    # If advanced tracker fails, fallback to unsmoothed detections
                     self.logger.warning(f"AdvancedTracker failed: {e}")
-                    # Continue without tracking if it fails
+                    for det in vehicle_processed_data:
+                        det["track_id"] = None
             
             # Step 3: Update tracking state
             self._update_tracking_state(vehicle_processed_data)
@@ -305,10 +350,9 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 zones=zones
             )
             general_counting_summary = calculate_counting_summary(
-                processed_data,
+                vehicle_processed_data,
                 zones=zones
             )
-            vehicle_counting_summary["detections"] = vehicle_processed_data
             
             # Step 5: Zone-based analysis if zones are configured (no tracking)
             zone_analysis = {}
@@ -336,6 +380,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
             frame_number = None
             if stream_info:
                 input_settings = stream_info.get("input_settings", {})
+                if isinstance(input_settings, list):
+                    input_settings = input_settings[0] if input_settings else {}
                 start_frame = input_settings.get("start_frame")
                 end_frame = input_settings.get("end_frame")
                 if start_frame is not None and end_frame is not None and start_frame == end_frame:
@@ -398,13 +444,16 @@ class VehicleMonitoringUseCase(BaseProcessor):
                 context=context
             )
     
-    def _update_tracking_state(self, detections: List[Dict]) -> None:
-        """Update tracking state with current frame data."""
-        if not detections:
+    def _update_tracking_state(self, vehicle_detections: List[Dict]) -> None:
+        """Update tracking state with current frame vehicle detections."""
+        if not vehicle_detections:
+            self._current_frame_track_ids = set()
+            self._last_update_time = time.time()
+            self.logger.debug("No vehicle detections provided, cleared current frame tracks")
             return
         
         current_frame_tracks = set()
-        for detection in detections:
+        for detection in vehicle_detections:
             track_id = detection.get("track_id")
             if track_id is not None:
                 current_frame_tracks.add(track_id)
@@ -417,14 +466,13 @@ class VehicleMonitoringUseCase(BaseProcessor):
         
         if len(current_frame_tracks) > 0:
             new_tracks = current_frame_tracks - (self._total_track_ids - current_frame_tracks)
-            if new_tracks:
-                self.logger.debug(f"Tracking state updated: {len(new_tracks)} new track IDs added, total unique tracks: {self._total_count}")
-            else:
-                self.logger.debug(f"Tracking state updated: {len(current_frame_tracks)} current frame tracks, total unique tracks: {self._total_count}")
+            self.logger.debug(f"Tracking state updated: {len(new_tracks)} new track IDs, total unique tracks: {self._total_count}, current frame tracks: {len(current_frame_tracks)}")
+        else:
+            self.logger.debug(f"Tracking state updated: no new track IDs, total unique tracks: {self._total_count}, current frame tracks: 0")
     
     def get_track_ids_info(self) -> Dict[str, Any]:
-        """Get detailed information about track IDs."""
-        return {
+        """Get detailed information about vehicle track IDs."""
+        info = {
             "total_count": self._total_count,
             "current_frame_count": len(self._current_frame_track_ids),
             "total_unique_track_ids": len(self._total_track_ids),
@@ -432,6 +480,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
             "last_update_time": self._last_update_time,
             "total_frames_processed": self._total_frame_counter
         }
+        self.logger.debug(f"Track IDs info: {info}")
+        return info
     
     def get_total_count(self) -> int:
         """Get the total count of unique vehicles tracked."""
@@ -636,10 +686,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
             "track_id": item.get("track_id")
         }
     
-
     def _generate_summary(self, counting_summary: Dict, zone_analysis: Dict, alerts: List) -> str:
         """Generate human-readable summary."""
-        
         total_vehicles = counting_summary.get("total_objects", 0)
         
         if total_vehicles == 0:
@@ -653,8 +701,6 @@ class VehicleMonitoringUseCase(BaseProcessor):
         
         return ", ".join(summary_parts)
     
-    
-    
     def _generate_events(self, counting_summary: Dict, zone_analysis: Dict, alerts: List, config: VehicleMonitoringConfig, frame_number: Optional[int] = None) -> List[Dict]:
         """Generate structured events for the output format with frame-based keys."""
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
@@ -799,17 +845,19 @@ class VehicleMonitoringUseCase(BaseProcessor):
         return tracking_stats
     
     def _generate_human_text_for_tracking(self, counting_summary: Dict, zone_analysis: Dict, insights: List[str], summary: str, config: VehicleMonitoringConfig) -> str:
-        """Generate human-readable text for tracking stats."""
+        """Generate human-readable text for vehicle tracking stats."""
         category_counts = counting_summary.get("by_category", {})
         total_vehicles = counting_summary.get("total_objects", 0)
         unique_count = self.get_total_count()
         
         parts = []
         if total_vehicles > 0:
-            parts.append(f"People Detected: {total_vehicles}")
+            parts.append(f"Vehicles Detected: {total_vehicles}")
             parts.append(f"Total Unique Vehicles: {unique_count}")
             for category, count in category_counts.items():
                 if count > 0 and category in config.target_vehicle_categories:
                     parts.append(f"{count} {category}{'s' if count != 1 else ''}")
         
-        return "\n".join(parts) if parts else "No vehicles detected"
\ No newline at end of file
+        text =  "\n".join(parts) if parts else "No vehicles detected"
+        print(text)
+        return text
\ No newline at end of file
